@@ -212,11 +212,14 @@ class Config(object):
         """
         return os.path.join(package_dir, "templates")
 
-    def get_section(self, name):
+    def get_section(self, name, default=None):
         """Return all the configuration options from a given .ini file section
         as a dictionary.
 
         """
+        if not self.file_config.has_section(name):
+            return default
+
         return dict(self.file_config.items(name))
 
     def set_main_option(self, name, value):
@@ -293,7 +296,7 @@ class CommandLine(object):
         self._generate_args(prog)
 
     def _generate_args(self, prog):
-        def add_options(parser, positional, kwargs):
+        def add_options(fn, parser, positional, kwargs):
             kwargs_opts = {
                 "template": (
                     "-t",
@@ -422,6 +425,22 @@ class CommandLine(object):
                         help="Indicate the current revision",
                     ),
                 ),
+                "purge": (
+                    "--purge",
+                    dict(
+                        action="store_true",
+                        help="Unconditionally erase the version table "
+                        "before stamping",
+                    ),
+                ),
+                "package": (
+                    "--package",
+                    dict(
+                        action="store_true",
+                        help="Write empty __init__.py files to the "
+                        "environment and version locations",
+                    ),
+                ),
             }
             positional_help = {
                 "directory": "location of scripts directory",
@@ -435,20 +454,28 @@ class CommandLine(object):
                     parser.add_argument(*args, **kw)
 
             for arg in positional:
-                if arg == "revisions":
+                if (
+                    arg == "revisions"
+                    or fn in positional_translations
+                    and positional_translations[fn][arg] == "revisions"
+                ):
                     subparser.add_argument(
-                        arg, nargs="+", help=positional_help.get(arg)
+                        "revisions",
+                        nargs="+",
+                        help=positional_help.get("revisions"),
                     )
                 else:
                     subparser.add_argument(arg, help=positional_help.get(arg))
 
         parser = ArgumentParser(prog=prog)
+
         parser.add_argument(
             "-c",
             "--config",
             type=str,
-            default="alembic.ini",
-            help="Alternate config file",
+            default=os.environ.get("ALEMBIC_CONFIG", "alembic.ini"),
+            help="Alternate config file; defaults to value of "
+            'ALEMBIC_CONFIG environment variable, or "alembic.ini"',
         )
         parser.add_argument(
             "-n",
@@ -471,6 +498,8 @@ class CommandLine(object):
         )
         subparsers = parser.add_subparsers()
 
+        positional_translations = {command.stamp: {"revision": "revisions"}}
+
         for fn in [getattr(command, n) for n in dir(command)]:
             if (
                 inspect.isfunction(fn)
@@ -486,6 +515,12 @@ class CommandLine(object):
                     positional = spec[0][1:]
                     kwarg = []
 
+                if fn in positional_translations:
+                    positional = [
+                        positional_translations[fn].get(name, name)
+                        for name in positional
+                    ]
+
                 # parse first line(s) of helptext without a line break
                 help_ = fn.__doc__
                 if help_:
@@ -500,7 +535,7 @@ class CommandLine(object):
                 subparser = subparsers.add_parser(
                     fn.__name__, help=" ".join(help_text)
                 )
-                add_options(subparser, positional, kwarg)
+                add_options(fn, subparser, positional, kwarg)
                 subparser.set_defaults(cmd=(fn, positional, kwarg))
         self.parser = parser
 
