@@ -1,16 +1,49 @@
+import collections
+import inspect
 import io
 import sys
 
-if sys.version_info < (2, 7):
-    raise NotImplementedError("Python 2.7 or greater is required.")
-
 py27 = sys.version_info >= (2, 7)
 py2k = sys.version_info.major < 3
 py3k = sys.version_info.major >= 3
-py33 = sys.version_info >= (3, 3)
 py35 = sys.version_info >= (3, 5)
 py36 = sys.version_info >= (3, 6)
 
+
+ArgSpec = collections.namedtuple(
+    "ArgSpec", ["args", "varargs", "keywords", "defaults"]
+)
+
+
+def inspect_getargspec(func):
+    """getargspec based on fully vendored getfullargspec from Python 3.3."""
+
+    if inspect.ismethod(func):
+        func = func.__func__
+    if not inspect.isfunction(func):
+        raise TypeError("{!r} is not a Python function".format(func))
+
+    co = func.__code__
+    if not inspect.iscode(co):
+        raise TypeError("{!r} is not a code object".format(co))
+
+    nargs = co.co_argcount
+    names = co.co_varnames
+    nkwargs = co.co_kwonlyargcount if py3k else 0
+    args = list(names[:nargs])
+
+    nargs += nkwargs
+    varargs = None
+    if co.co_flags & inspect.CO_VARARGS:
+        varargs = co.co_varnames[nargs]
+        nargs = nargs + 1
+    varkw = None
+    if co.co_flags & inspect.CO_VARKEYWORDS:
+        varkw = co.co_varnames[nargs]
+
+    return ArgSpec(args, varargs, varkw, func.__defaults__)
+
+
 if py3k:
     from io import StringIO
 else:
@@ -50,27 +83,11 @@ else:
 
     range = xrange  # noqa
 
-if py33:
+if py3k:
     import collections.abc as collections_abc
 else:
     import collections as collections_abc  # noqa
 
-if py3k:
-    import collections
-
-    ArgSpec = collections.namedtuple(
-        "ArgSpec", ["args", "varargs", "keywords", "defaults"]
-    )
-
-    from inspect import getfullargspec as inspect_getfullargspec
-
-    def inspect_getargspec(func):
-        return ArgSpec(*inspect_getfullargspec(func)[0:4])
-
-
-else:
-    from inspect import getargspec as inspect_getargspec  # noqa
-
 if py35:
     from inspect import formatannotation
 
@@ -201,11 +218,17 @@ if py3k:
         return suffixes
 
     def has_pep3147():
-        # http://www.python.org/dev/peps/pep-3147/#detecting-pep-3147-availability
 
-        import imp
+        if py35:
+            return True
+        else:
+            # TODO: not sure if we are supporting old versions of Python
+            # the import here emits a deprecation warning which the test
+            # suite only catches if imp wasn't imported alreadt
+            # http://www.python.org/dev/peps/pep-3147/#detecting-pep-3147-availability
+            import imp
 
-        return hasattr(imp, "get_tag")
+            return hasattr(imp, "get_tag")
 
 
 else:
@@ -300,7 +323,7 @@ class EncodedIO(io.TextIOWrapper):
 if py2k:
     # in Py2K, the io.* package is awkward because it does not
     # easily wrap the file type (e.g. sys.stdout) and I can't
-    # figure out at all how to wrap StringIO.StringIO (used by nosetests)
+    # figure out at all how to wrap StringIO.StringIO
     # and also might be user specified too.  So create a full
     # adapter.
 
